$set 3 #Configmenu

$ #ConfigOptions
# ꥪץ
$ #FocusModel
# եǥ
$ #WindowPlacement
# ɥ
$ #ImageDithering
# ǥ
$ #OpaqueMove
# ɥƤɽޤްư
$ #FullMax
# 粽(С̵)
$ #FocusNew
# ɥ˥ե
$ #FocusLast
# ڡư˺ǸΥɥ˥ե
$ #ClickToFocus
# åǥե
$ #SloppyFocus
# 륪Сǥե
$ #AutoRaise
# եƤȤ˺̤˰ư
$ #SmartRows
#  (:ROW)
$ #SmartCols
#  (:COL)
$ #Cascade
# 
$ #LeftRight
# 鱦
$ #RightLeft
# 麸
$ #TopBottom
# 夫鲼
$ #BottomTop
# 
$ #Tabs
# ֤ɽ
$ #Icons
# ɽ
$ #TabPlacement
# ֤ɽ
$ #TabRotateVertical
# ֤μưž
$ #SemiSloppyFocus
# 륪Сǥե(SemiSloppy)
$ #MaxOverSlit
# Slitۤƺ粽
$ #SloppyWindowGrouping
# Window˥֥ɥåפǤ⥿֥롼פ
$ #WorkspaceWarping
# Workspace Warping
